@@ -3,12 +3,12 @@ import {Seq} from 'immutable';
 import FormSelect from '../../components/style/form-select';
 import FormLabel from '../../components/style/form-label'
 
-export default function PropertyEnum({propertyName, value, onUpdate, configs}) {
+export default function PropertyEnum({value, onUpdate, configs}) {
 
   return (
     <div style={{marginBottom: "3px"}}>
       <div style={{display: "inline-block", width: "30%"}}>
-        <FormLabel>{propertyName}</FormLabel>
+        <FormLabel>{configs.label}</FormLabel>
       </div>
       <div style={{display: "inline-block", width: "70%"}}>
         <FormSelect value={value} onChange={event => onUpdate(event.target.value)}>
@@ -23,7 +23,6 @@ export default function PropertyEnum({propertyName, value, onUpdate, configs}) {
 }
 
 PropertyEnum.propTypes = {
-  propertyName: PropTypes.string.isRequired,
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired,
